@@ -3,11 +3,16 @@ import sys
 
 from . import basketcase
 
+
 def main():
     """Handle command-line script execution."""
 
     parser = argparse.ArgumentParser(description='Fetch resources from Instagram.')
-    parser.add_argument('input_file', type=argparse.FileType('r'), help='A list of URLs separated by newline characters')
+    parser.add_argument(
+        'input_file',
+        type=argparse.FileType('r'),
+        help='A list of URLs separated by newline characters'
+    )
     args = parser.parse_args()
 
     urls = set()
@@ -27,5 +32,6 @@ def main():
 
     return 0
 
+
 if __name__ == '__main__':
     sys.exit(main())
