@@ -7,10 +7,11 @@ if typing.TYPE_CHECKING:
     import requests
     from . import storage
 
+
 class Authenticator:
-    def __init__(self, http_client: 'requests.Session', storage: 'storage.Storage'):
+    def __init__(self, http_client: 'requests.Session', storage_manager: 'storage.Storage'):
         self._http_client = http_client
-        self._storage = storage
+        self._storage = storage_manager
 
         self._http_client.cookies = self._storage.get_cookie_jar()
         self._username = self._storage.get_user()
@@ -71,8 +72,8 @@ class Authenticator:
 
         with self._http_client.post(
             'https://www.instagram.com/accounts/login/ajax/',
-            data = data,
-            headers = custom_headers
+            data=data,
+            headers=custom_headers
         ) as response:
             return response.json()
 
@@ -88,14 +89,14 @@ class Authenticator:
             'trust_signal': 'true',
             'username': username,
             'verificationCode': code,
-            'verification_method': '3', # is 3 == totp?
+            'verification_method': '3',  # is 3 == totp?
             'queryParams': '{"next":"/"}'
         }
 
         with self._http_client.post(
             'https://www.instagram.com/accounts/login/ajax/two_factor/',
-            data = data,
-            headers = custom_headers
+            data=data,
+            headers=custom_headers
         ) as response:
             return response.json()
 
@@ -164,4 +165,4 @@ class Authenticator:
             else:
                 raise authentication_failed
         else:
-            raise authentication_failed
\ No newline at end of file
+            raise authentication_failed
